diff --git a/CHANGELOG.adoc b/CHANGELOG.adoc
index ba9e069edf..5c913eea5a 100644
--- a/CHANGELOG.adoc
+++ b/CHANGELOG.adoc
@@ -22,6 +22,11 @@ include::content/docs/variables.adoc-include[]
* The `html` field type will be removed in the future. Instead the `string` type will be used in combination with an additional configuration property for this field in the schema. Of course, your existing schemas will be migrated for you.
+[[v1.10.0]]
+== 1.10.0 (TBD)
+
+icon:check[] Core: The OrientDB database as been updated to version 3.2.10.
+
[[v1.9.3]]
== 1.9.3 (22.09.2022)
diff --git a/api/pom.xml b/api/pom.xml
index 976efe80fb..6997f2d03d 100644
--- a/api/pom.xml
+++ b/api/pom.xml
@@ -11,7 +11,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/bom/pom.xml b/bom/pom.xml
index fc3047f234..24ce87ad86 100644
--- a/bom/pom.xml
+++ b/bom/pom.xml
@@ -11,7 +11,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
@@ -25,7 +25,7 @@
5.5.7
${project.version}
1.1.1
- 3.1.18
+ 3.2.10
3.12.8
2.13.2
2.13.2
diff --git a/changelog-system/pom.xml b/changelog-system/pom.xml
index 6d51466343..fd9db5113a 100644
--- a/changelog-system/pom.xml
+++ b/changelog-system/pom.xml
@@ -12,7 +12,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/common-api/pom.xml b/common-api/pom.xml
index 45e9053375..f1be98e7a7 100644
--- a/common-api/pom.xml
+++ b/common-api/pom.xml
@@ -11,7 +11,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/common/pom.xml b/common/pom.xml
index b5205b2ef1..3d92168dbd 100644
--- a/common/pom.xml
+++ b/common/pom.xml
@@ -11,7 +11,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/core/pom.xml b/core/pom.xml
index 5cab13035e..28ce045b30 100644
--- a/core/pom.xml
+++ b/core/pom.xml
@@ -11,7 +11,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/databases/orientdb/pom.xml b/databases/orientdb/pom.xml
index ac7f28bfe0..0b1bf29732 100644
--- a/databases/orientdb/pom.xml
+++ b/databases/orientdb/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh-databases
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/databases/pom.xml b/databases/pom.xml
index b268847678..21411812f6 100644
--- a/databases/pom.xml
+++ b/databases/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/demo/common/pom.xml b/demo/common/pom.xml
index 2eff4b186d..a55776f006 100644
--- a/demo/common/pom.xml
+++ b/demo/common/pom.xml
@@ -11,7 +11,7 @@
com.gentics.mesh
mesh-demos
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/demo/default/pom.xml b/demo/default/pom.xml
index 1abe7559d3..b11ed007f0 100644
--- a/demo/default/pom.xml
+++ b/demo/default/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh-demos
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/demo/pom.xml b/demo/pom.xml
index b1f4eceb2f..ed170be734 100644
--- a/demo/pom.xml
+++ b/demo/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/distributed-coordinator/pom.xml b/distributed-coordinator/pom.xml
index ad7758e8ca..8cc4442e10 100644
--- a/distributed-coordinator/pom.xml
+++ b/distributed-coordinator/pom.xml
@@ -7,7 +7,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
mesh-distributed-coordinator
diff --git a/distributed/pom.xml b/distributed/pom.xml
index c9d3d77b64..c87faab832 100644
--- a/distributed/pom.xml
+++ b/distributed/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/doc/pom.xml b/doc/pom.xml
index 1c89ca3033..6529c3d588 100644
--- a/doc/pom.xml
+++ b/doc/pom.xml
@@ -6,7 +6,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
mesh-doc
diff --git a/elasticsearch/pom.xml b/elasticsearch/pom.xml
index 5a324135f1..59b70503b4 100644
--- a/elasticsearch/pom.xml
+++ b/elasticsearch/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/ferma/pom.xml b/ferma/pom.xml
index fd9af4a25a..a2d1fa4ae8 100644
--- a/ferma/pom.xml
+++ b/ferma/pom.xml
@@ -6,7 +6,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
ferma
@@ -40,10 +40,24 @@
com.orientechnologies
orientdb-core
+
+
+
+ org.graalvm.tools
+ chromeinspector
+
+
com.orientechnologies
orientdb-graphdb
+
+
+
+ org.graalvm.tools
+ chromeinspector
+
+
com.google.code.gson
diff --git a/madl/api/pom.xml b/madl/api/pom.xml
index e8d14e05e0..c9c149549f 100644
--- a/madl/api/pom.xml
+++ b/madl/api/pom.xml
@@ -6,7 +6,7 @@
com.gentics.mesh
madl
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
madl-api
diff --git a/madl/core/pom.xml b/madl/core/pom.xml
index a5a45196ff..4b3c894e6d 100644
--- a/madl/core/pom.xml
+++ b/madl/core/pom.xml
@@ -6,7 +6,7 @@
com.gentics.mesh
madl
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
madl-core
diff --git a/madl/madl-ferma/pom.xml b/madl/madl-ferma/pom.xml
index 4475a1d2e3..fd9220c3be 100644
--- a/madl/madl-ferma/pom.xml
+++ b/madl/madl-ferma/pom.xml
@@ -6,7 +6,7 @@
com.gentics.mesh
madl
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
madl-ferma
diff --git a/madl/orientdb/pom.xml b/madl/orientdb/pom.xml
index c7cab6094c..c6fb997a54 100644
--- a/madl/orientdb/pom.xml
+++ b/madl/orientdb/pom.xml
@@ -7,7 +7,7 @@
com.gentics.mesh
madl
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
madl-orientdb
@@ -25,19 +25,47 @@
com.orientechnologies
orientdb-core
+
+
+
+ org.graalvm.tools
+ chromeinspector
+
+
com.orientechnologies
orientdb-server
+
+
+
+ org.graalvm.tools
+ chromeinspector
+
+
com.orientechnologies
orientdb-distributed
+
+
+
+ org.graalvm.tools
+ chromeinspector
+
+
com.orientechnologies
orientdb-graphdb
+
+
+
+ org.graalvm.tools
+ chromeinspector
+
+
com.orientechnologies
diff --git a/madl/pom.xml b/madl/pom.xml
index 91d10d0876..bf2ba1cc72 100644
--- a/madl/pom.xml
+++ b/madl/pom.xml
@@ -7,7 +7,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
madl
diff --git a/mdm/api/pom.xml b/mdm/api/pom.xml
index dd5746026a..c8f223f029 100644
--- a/mdm/api/pom.xml
+++ b/mdm/api/pom.xml
@@ -7,7 +7,7 @@
com.gentics.mesh
mesh-mdm
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
mesh-mdm-api
diff --git a/mdm/common/pom.xml b/mdm/common/pom.xml
index c312d0ac2b..8196259dfc 100644
--- a/mdm/common/pom.xml
+++ b/mdm/common/pom.xml
@@ -7,7 +7,7 @@
com.gentics.mesh
mesh-mdm
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
mesh-mdm-common
diff --git a/mdm/orientdb-api/pom.xml b/mdm/orientdb-api/pom.xml
index ab63ffb352..0a01a50af1 100644
--- a/mdm/orientdb-api/pom.xml
+++ b/mdm/orientdb-api/pom.xml
@@ -7,7 +7,7 @@
com.gentics.mesh
mesh-mdm
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
mesh-mdm-orientdb-api
@@ -34,19 +34,47 @@
com.orientechnologies
orientdb-core
+
+
+
+ org.graalvm.tools
+ chromeinspector
+
+
com.orientechnologies
orientdb-server
+
+
+
+ org.graalvm.tools
+ chromeinspector
+
+
com.orientechnologies
orientdb-distributed
+
+
+
+ org.graalvm.tools
+ chromeinspector
+
+
com.orientechnologies
orientdb-graphdb
+
+
+
+ org.graalvm.tools
+ chromeinspector
+
+
diff --git a/mdm/orientdb-wrapper/pom.xml b/mdm/orientdb-wrapper/pom.xml
index 687616fc6d..75b144164a 100644
--- a/mdm/orientdb-wrapper/pom.xml
+++ b/mdm/orientdb-wrapper/pom.xml
@@ -7,7 +7,7 @@
com.gentics.mesh
mesh-mdm
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
mesh-mdm-orientdb-wrapper
diff --git a/mdm/pom.xml b/mdm/pom.xml
index 8efdfc56e7..91d3762004 100644
--- a/mdm/pom.xml
+++ b/mdm/pom.xml
@@ -7,7 +7,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
mesh-mdm
diff --git a/performance-tests/pom.xml b/performance-tests/pom.xml
index 8282473a69..6e21406bbd 100644
--- a/performance-tests/pom.xml
+++ b/performance-tests/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/plugin-api/pom.xml b/plugin-api/pom.xml
index 5c50f4e675..3da0ab0022 100644
--- a/plugin-api/pom.xml
+++ b/plugin-api/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/plugin-bom/pom.xml b/plugin-bom/pom.xml
index 004d29e042..6b605333b5 100644
--- a/plugin-bom/pom.xml
+++ b/plugin-bom/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/plugin-dep/pom.xml b/plugin-dep/pom.xml
index c476738b52..e9727f64dd 100644
--- a/plugin-dep/pom.xml
+++ b/plugin-dep/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/plugin-parent/pom.xml b/plugin-parent/pom.xml
index 34ac2408f2..18d1a34a19 100644
--- a/plugin-parent/pom.xml
+++ b/plugin-parent/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/pom.xml b/pom.xml
index 3b32fd27fb..1eeb3c57ce 100644
--- a/pom.xml
+++ b/pom.xml
@@ -6,7 +6,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
pom
Gentics Mesh
diff --git a/rest-client/pom.xml b/rest-client/pom.xml
index addf481370..62d20f577c 100644
--- a/rest-client/pom.xml
+++ b/rest-client/pom.xml
@@ -11,7 +11,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/rest-model/pom.xml b/rest-model/pom.xml
index ae17e8c156..ca7858e4a9 100644
--- a/rest-model/pom.xml
+++ b/rest-model/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/server/pom.xml b/server/pom.xml
index ad33b07f5c..408b027fa1 100644
--- a/server/pom.xml
+++ b/server/pom.xml
@@ -11,7 +11,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/services/aws-s3-storage/pom.xml b/services/aws-s3-storage/pom.xml
index 22745d58a4..077f98c914 100644
--- a/services/aws-s3-storage/pom.xml
+++ b/services/aws-s3-storage/pom.xml
@@ -11,7 +11,7 @@
com.gentics.mesh
mesh-services
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/services/image-imgscalr/pom.xml b/services/image-imgscalr/pom.xml
index d91c32a83e..ab64012347 100644
--- a/services/image-imgscalr/pom.xml
+++ b/services/image-imgscalr/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh-services
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/services/jwt-auth/pom.xml b/services/jwt-auth/pom.xml
index 666b0ae26a..68e9b93186 100644
--- a/services/jwt-auth/pom.xml
+++ b/services/jwt-auth/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh-services
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/services/local-storage/pom.xml b/services/local-storage/pom.xml
index d06fa11eaf..54c8c6a677 100644
--- a/services/local-storage/pom.xml
+++ b/services/local-storage/pom.xml
@@ -9,7 +9,7 @@
com.gentics.mesh
mesh-services
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/services/metrics-prometheus/pom.xml b/services/metrics-prometheus/pom.xml
index ae8c4dd313..73a5f47022 100644
--- a/services/metrics-prometheus/pom.xml
+++ b/services/metrics-prometheus/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh-services
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/services/pom.xml b/services/pom.xml
index b80baa4e57..81bdcdfd6a 100644
--- a/services/pom.xml
+++ b/services/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/tests/api/pom.xml b/tests/api/pom.xml
index ba75b9321b..133d898d88 100644
--- a/tests/api/pom.xml
+++ b/tests/api/pom.xml
@@ -5,7 +5,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
mesh-tests-api
Mesh - Tests API
diff --git a/tests/common/pom.xml b/tests/common/pom.xml
index b038a605a0..658aed69b0 100644
--- a/tests/common/pom.xml
+++ b/tests/common/pom.xml
@@ -11,7 +11,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/tests/context-api/pom.xml b/tests/context-api/pom.xml
index 7a68fa31a1..8d8fcca1e0 100644
--- a/tests/context-api/pom.xml
+++ b/tests/context-api/pom.xml
@@ -5,7 +5,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
mesh-tests-context-api
Mesh - Tests context API
diff --git a/tests/context-orientdb/pom.xml b/tests/context-orientdb/pom.xml
index 962b8ab987..73feda3025 100644
--- a/tests/context-orientdb/pom.xml
+++ b/tests/context-orientdb/pom.xml
@@ -3,7 +3,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
mesh-tests-context-orientdb
Mesh - Tests context - OrientDB
diff --git a/tests/orientdb-runner/pom.xml b/tests/orientdb-runner/pom.xml
index a6b9837e23..f856ac41a9 100644
--- a/tests/orientdb-runner/pom.xml
+++ b/tests/orientdb-runner/pom.xml
@@ -5,7 +5,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
mesh-orientdb-tests-runner
Mesh - Tests Runner - OrientDB
diff --git a/tests/pom.xml b/tests/pom.xml
index 7f87fc4bc7..41e54640bc 100644
--- a/tests/pom.xml
+++ b/tests/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/tests/tests-admin-gui/pom.xml b/tests/tests-admin-gui/pom.xml
index 7dffaca031..4362a45df2 100644
--- a/tests/tests-admin-gui/pom.xml
+++ b/tests/tests-admin-gui/pom.xml
@@ -5,7 +5,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
tests-mesh-admin-gui
Mesh Admin GUI - Shared tests
diff --git a/tests/tests-api/pom.xml b/tests/tests-api/pom.xml
index cec8e4b5ae..ad2bb563d5 100644
--- a/tests/tests-api/pom.xml
+++ b/tests/tests-api/pom.xml
@@ -8,7 +8,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/tests/tests-changelog-system/pom.xml b/tests/tests-changelog-system/pom.xml
index d729e022a8..f81ee86f9a 100644
--- a/tests/tests-changelog-system/pom.xml
+++ b/tests/tests-changelog-system/pom.xml
@@ -5,7 +5,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
tests-mesh-changelog-system
Mesh Changelog System - Shared tests
diff --git a/tests/tests-common/pom.xml b/tests/tests-common/pom.xml
index 316689100a..dfe52bcfa9 100644
--- a/tests/tests-common/pom.xml
+++ b/tests/tests-common/pom.xml
@@ -8,7 +8,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/tests/tests-core/pom.xml b/tests/tests-core/pom.xml
index c9f4bd26b4..7083f7eb43 100644
--- a/tests/tests-core/pom.xml
+++ b/tests/tests-core/pom.xml
@@ -8,7 +8,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/tests/tests-distributed-coordinator/pom.xml b/tests/tests-distributed-coordinator/pom.xml
index 59f07eca1d..45c563c8dd 100644
--- a/tests/tests-distributed-coordinator/pom.xml
+++ b/tests/tests-distributed-coordinator/pom.xml
@@ -5,7 +5,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
tests-mesh-distributed-coordinator
Mesh Distributed Coordinator - Shared tests
diff --git a/tests/tests-distributed/pom.xml b/tests/tests-distributed/pom.xml
index e444762017..5fe1d90554 100644
--- a/tests/tests-distributed/pom.xml
+++ b/tests/tests-distributed/pom.xml
@@ -11,7 +11,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/tests/tests-elasticsearch/pom.xml b/tests/tests-elasticsearch/pom.xml
index 7ae4797bcf..07b5457614 100644
--- a/tests/tests-elasticsearch/pom.xml
+++ b/tests/tests-elasticsearch/pom.xml
@@ -5,7 +5,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
tests-mesh-elasticsearch
Mesh Elasticsearch - Shared tests
diff --git a/tests/tests-plugin-api/pom.xml b/tests/tests-plugin-api/pom.xml
index ffc7add664..32630a1a82 100644
--- a/tests/tests-plugin-api/pom.xml
+++ b/tests/tests-plugin-api/pom.xml
@@ -5,7 +5,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
tests-mesh-plugin-api
Mesh Plugin API - Shared tests
diff --git a/tests/tests-rest-client/pom.xml b/tests/tests-rest-client/pom.xml
index 47b527fa05..ace65c6c9d 100644
--- a/tests/tests-rest-client/pom.xml
+++ b/tests/tests-rest-client/pom.xml
@@ -5,7 +5,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
tests-mesh-rest-client
Mesh REST Client - Shared tests
diff --git a/tests/tests-rest-model/pom.xml b/tests/tests-rest-model/pom.xml
index 49a0e8a0a6..f7f0dbccaa 100644
--- a/tests/tests-rest-model/pom.xml
+++ b/tests/tests-rest-model/pom.xml
@@ -5,7 +5,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
tests-mesh-rest-model
Mesh REST Model - Shared tests
diff --git a/tests/tests-server/pom.xml b/tests/tests-server/pom.xml
index 5405ecbcc2..e3256911bb 100644
--- a/tests/tests-server/pom.xml
+++ b/tests/tests-server/pom.xml
@@ -5,7 +5,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
tests-mesh-server
Mesh Server - Shared tests
diff --git a/tests/tests-service-aws-s3-storage/pom.xml b/tests/tests-service-aws-s3-storage/pom.xml
index 0a1b6ea1dd..20acbe1c0d 100644
--- a/tests/tests-service-aws-s3-storage/pom.xml
+++ b/tests/tests-service-aws-s3-storage/pom.xml
@@ -5,7 +5,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
tests-mesh-service-aws-s3-storage
Mesh AWS S3 Storage - Shared tests
diff --git a/tests/tests-service-image-imgscalr/pom.xml b/tests/tests-service-image-imgscalr/pom.xml
index 720a0c9345..e04304ed8a 100644
--- a/tests/tests-service-image-imgscalr/pom.xml
+++ b/tests/tests-service-image-imgscalr/pom.xml
@@ -5,7 +5,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
tests-mesh-service-image-imgscalr
Mesh Imgscalr Service - Shared tests
diff --git a/tests/tests-service-jwt-auth/pom.xml b/tests/tests-service-jwt-auth/pom.xml
index 021de3749d..94ff8b922e 100644
--- a/tests/tests-service-jwt-auth/pom.xml
+++ b/tests/tests-service-jwt-auth/pom.xml
@@ -5,7 +5,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
tests-mesh-service-jwt-auth
Mesh JWT Authentication - Shared tests
diff --git a/tests/tests-service-local-storage/pom.xml b/tests/tests-service-local-storage/pom.xml
index ee717834cf..660fe7e355 100644
--- a/tests/tests-service-local-storage/pom.xml
+++ b/tests/tests-service-local-storage/pom.xml
@@ -5,7 +5,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
tests-mesh-service-local-storage
Mesh Local Storage - Shared tests
diff --git a/tests/tests-service-metrics-prometheus/pom.xml b/tests/tests-service-metrics-prometheus/pom.xml
index 360d5a7249..3d792dca2f 100644
--- a/tests/tests-service-metrics-prometheus/pom.xml
+++ b/tests/tests-service-metrics-prometheus/pom.xml
@@ -5,7 +5,7 @@
com.gentics.mesh
mesh-tests
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
tests-mesh-service-metrics-prometheus
Mesh Prometeus Metrics Service - Shared tests
diff --git a/verticles/admin-gui/pom.xml b/verticles/admin-gui/pom.xml
index ebb248cea6..e868f11954 100644
--- a/verticles/admin-gui/pom.xml
+++ b/verticles/admin-gui/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh-verticles
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/verticles/graphql/pom.xml b/verticles/graphql/pom.xml
index 1bc7736683..ab7bc0197e 100644
--- a/verticles/graphql/pom.xml
+++ b/verticles/graphql/pom.xml
@@ -9,7 +9,7 @@
com.gentics.mesh
mesh-verticles
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/verticles/pom.xml b/verticles/pom.xml
index 2299712bb9..36e0736941 100644
--- a/verticles/pom.xml
+++ b/verticles/pom.xml
@@ -9,7 +9,7 @@
com.gentics.mesh
mesh
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/verticles/rest/pom.xml b/verticles/rest/pom.xml
index 6fa4c3b8d0..abd63cd3e8 100644
--- a/verticles/rest/pom.xml
+++ b/verticles/rest/pom.xml
@@ -10,7 +10,7 @@
com.gentics.mesh
mesh-verticles
- 1.9.4-SNAPSHOT
+ 1.10.0-SNAPSHOT
diff --git a/databases/orientdb/src/main/java/com/gentics/mesh/graphdb/cluster/OrientDBClusterManagerImpl.java b/databases/orientdb/src/main/java/com/gentics/mesh/graphdb/cluster/OrientDBClusterManagerImpl.java
index 2b433dc903..1b40191ab0 100644
--- a/databases/orientdb/src/main/java/com/gentics/mesh/graphdb/cluster/OrientDBClusterManagerImpl.java
+++ b/databases/orientdb/src/main/java/com/gentics/mesh/graphdb/cluster/OrientDBClusterManagerImpl.java
@@ -578,7 +578,7 @@ public boolean isWriteQuorumReached() {
/**
* Check whether any of the cluster members is set to have exceeded the disk quota
* @return Optional name of the (first found) instance having the disk quota exceeded
*/
public Optional getInstanceDiskQuotaExceeded() {
if (!isClusteringEnabled || hazelcastPlugin == null) {
@@ -586,7 +586,7 @@ public Optional getInstanceDiskQuotaExceeded() {
} else {
return hazelcastPlugin.getHazelcastInstance().getCluster().getMembers().stream()
.filter(m -> m.getBooleanAttribute(MESH_MEMBER_DISK_QUOTA_EXCEEDED) == Boolean.TRUE)
- .map(m -> hazelcastPlugin.getNodeName(m)).findFirst();
+ .map(m -> m.getUuid()).findFirst();
}
}
@@ -578,7 +578,7 @@ public boolean isWriteQuorumReached() {
/**
* Check whether any of the cluster members is set to have exceeded the disk quota
- * @return Optional name of the (first found) instance having the disk quota exceeded
+ * @return Optional uuid of the (first found) instance having the disk quota exceeded
*/
public Optional getInstanceDiskQuotaExceeded() {